@@ -7,5 +7,5 @@ def sanitize_column_reference(column_reference):
             table, column = column_reference.split('.')
             column_reference = ColumnReference(column, table=table)
         else:
-            raise Exception('Missing table in column reference')
-    return column_reference
\ No newline at end of file
+            raise Exception(f'Missing table in column reference <{column_reference}>')
+    return column_reference
